@@ -18,4 +18,15 @@ class DateTimeUtils():
             expiration_date = datetime.date.today() + datetime.timedelta(days=expiration)
         elif isinstance(expiration, datetime.date):
             expiration_date = expiration
-        return expiration_date
+        return expiration_date  # pylint: disable=possibly-used-before-assignment
+
+
+def from_iso_format(time):
+    """
+    Parse datetime object from ISO 8601 format
+
+    :param str time: Timestamp
+    :returns: Datetime object
+    :rtype: datetime.datetime
+    """
+    return datetime.datetime.fromisoformat(time)
