@@ -1,24 +1,21 @@
 __all__ = [
-    'connection',
     'activation',
+    'admins',
     'antivirus',
     'buckets',
+    'cloudfs',
+    'connection',
+    'devices',
     'directoryservice',
     'enum',
-    'login',
-    'query',
-    'logs',
-    'portals',
-    'reports',
-    'remote',
-    'servers',
-    'devices',
-    'session',
-    'admins',
-    'users',
-    'cloudfs',
-    'zones',
     'files',
-    'decorator',
-    'messaging'
+    'login',
+    'logs',
+    'messaging',
+    'portals',
+    'query',
+    'remote',
+    'reports',
+    'servers',
+    'users'
 ]
