@@ -644,3 +644,89 @@ class Reports:
     Portals = 'portalsStatisticsReport'
     Folders = 'foldersStatisticsReport'
     FolderGroups = 'folderGroupsStatisticsReport'
+
+
+class ConflictHandler:
+    """
+    Conflict Handler
+
+    :ivar str Skip: Skip.
+    :ivar str Overwrite: Overwrite target.
+    :ivar str Rename: Append date to file name.
+    """
+    Skip = 'Skip'
+    Overwrite = 'Override'
+    Rename = 'Rename'
+
+
+class UploadError:
+    """
+    Upload Error
+
+    :ivar str UserQuotaViolation: User is out of quota.
+    :ivar str FolderQuotaViolation: Directory is out of quota.
+    :ivar str PortalQuotaViolation: Team Portal is out of quota.
+    :ivar str RejectedByPolicy: Rejected by Cloud Drive policy rule.
+    :ivar str NoStorageBucket: No available storage bucket.
+    :ivar str WindowsACL: Illegal access to Windows ACL-enabled cloud drive folder.
+    """
+    FolderQuotaViolation = 'Folder is out of quota'
+    UserQuotaViolation = 'User is out of quota'
+    PortalQuotaViolation = 'Portal is out of quota'
+    RejectedByPolicy = "Rejected by Cloud Drive policy rule"
+    NoStorageBucket = "No available storage location"
+    WindowsACL = "Illegal access to NTACL folder"
+
+
+class ResourceScope:
+    """
+    Resource Scope
+
+    :ivar str Root: Root.
+    :ivar str ProjectsContainer: ProjectsContainer.
+    :ivar str Project: Project.
+    :ivar str SharedContainer: SharedContainer.
+    :ivar str SharedDomain: SharedDomain.
+    :ivar str Shared: Shared.
+    :ivar str BackupsContainer: BackupsContainer.
+    :ivar str Backup: Backup.
+    :ivar str Personal: Personal.
+    :ivar str UsersContainer: UsersContainer.
+    :ivar str UsersFoldersContainer: UsersFoldersContainer.
+    :ivar str CloudDrivesContainer: CloudDrivesContainer.
+    :ivar str OfflineFolder: OfflineFolder.
+    :ivar str InsideCloudFolder: InsideCloudFolder.
+    """
+    Root = "Root"
+    ProjectsContainer = "ProjectsContainer"
+    Project = "Project"
+    SharedContainer = "SharedContainer"
+    SharedDomain = "SharedDomain"
+    Shared = "Shared"
+    BackupsContainer = "BackupsContainer"
+    Backup = "Backup"
+    Personal = "Personal"
+    UsersContainer = "UsersContainer"
+    UsersFoldersContainer = "UsersFoldersContainer"
+    CloudDrivesContainer = "CloudDrivesContainer"
+    OfflineFolder = "OfflineFolder"
+    InsideCloudFolder = "InsideCloudFolder"
+
+
+class ResourceError:
+    """
+    Resource Error
+
+    :ivar str Conflict: Conflict.
+    :ivar str PermissionDenied: Permission denied.
+    :ivar str DestinationNotExists: Path validation error.
+    :ivar str FileWithTheSameNameExist: File exists.
+    :ivar str InvalidName: Invalid name.
+    :ivar str ReservedName: Reserved name.
+    """
+    Conflict = "Conflict"
+    PermissionDenied = "PermissionDenied"
+    DestinationNotExists = "DestinationNotExists"
+    FileWithTheSameNameExist = "FileWithTheSameNameExist"
+    InvalidName = "InvalidName"
+    ReservedName = "ReservedName"
