@@ -1,10 +1,14 @@
 import logging
 import time
 
-from ..exception import CTERAException, CTERAClientException, HostUnreachable, ExhaustedException
+from ..exceptions import CTERAException
+from ..exceptions.transport import HTTPError
 from .base_command import BaseCommand
 
 
+logger = logging.getLogger('cterasdk.core')
+
+
 class Startup(BaseCommand):
     """
     Server Startup APIs
@@ -16,11 +20,7 @@ class Startup(BaseCommand):
         """
         Get the server startup status
         """
-        response = None
-        try:
-            response = self._portal.get(f'/{self._portal.context}/startup', use_file_url=True)
-        except CTERAClientException as error:
-            return error.response.body.status
+        response = self._core.ctera.get('/startup')
         return response.status
 
     def wait(self, retries=120, seconds=5):
@@ -30,17 +30,17 @@ class Startup(BaseCommand):
         attempt = 0
         while True:
             try:
+                if attempt >= retries:
+                    logger.error('Timed out. Server did not start in a timely manner.')
+                    raise CTERAException('Timed out. Server did not start in a timely manner')
                 current_status = self.status()
                 if current_status == Startup.Started:
-                    logging.getLogger().info('Server started.')
+                    logger.info('Server started.')
                     break
-                logging.getLogger().debug('Current server status. %s', {'status': current_status})
+                logger.debug('Current server status. %s', {'status': current_status})
                 attempt = attempt + 1
-                if attempt >= retries:
-                    logging.getLogger().error('Timed out. Server did not start in a timely manner.')
-                    raise CTERAException('Timed out. Server did not start in a timely manner')
                 time.sleep(seconds)
-            except (HostUnreachable, ExhaustedException) as e:
-                logging.getLogger().debug('Exception. %s', e.__dict__)
+            except (ConnectionError, TimeoutError, HTTPError) as e:
+                logger.debug('Exception. %s', e.__dict__)
                 attempt = attempt + 1
                 time.sleep(seconds)
