@@ -1,10 +1,13 @@
 import logging
 
 from ..common import Object
-from ..exception import CTERAException
+from ..exceptions import CTERAException
 from .base_command import BaseCommand
 
 
+logger = logging.getLogger('cterasdk.core')
+
+
 class StorageClasses(BaseCommand):
     """ Portal Storage Classes APIs """
 
@@ -14,11 +17,11 @@ class StorageClasses(BaseCommand):
 
         :param str name: Name
         """
-        logging.getLogger().info("Adding storage class. %s", {'name': name})
+        logger.info("Adding storage class. %s", {'name': name})
         param = Object()
         param.name = name
-        response = self._portal.add('/storageClasses', param)
-        logging.getLogger().info("Storage class added. %s", {'name': name})
+        response = self._core.api.add('/storageClasses', param)
+        logger.info("Storage class added. %s", {'name': name})
         return response
 
     def all(self):
@@ -28,9 +31,9 @@ class StorageClasses(BaseCommand):
         :returns: List of storage classes
         :rtype: list(cterasdk.common.object.Object)
         """
-        if self._portal.session().in_tenant_context():
-            return self._portal.execute('', 'getStorageClasses')
-        return self._portal.get('/storageClasses')
+        if self._core.session().in_tenant_context():
+            return self._core.api.execute('', 'getStorageClasses')
+        return self._core.api.get('/storageClasses')
 
     def get(self, name):
         """
@@ -40,9 +43,10 @@ class StorageClasses(BaseCommand):
         :returns: Storage class
         :rtype: cterasdk.common.object.Object
         """
-        if not self._portal.session().in_tenant_context():
-            return self._portal.get(f'/storageClasses/{name}')
+        ref = f'/storageClasses/{name}'
+        if not self._core.session().in_tenant_context():
+            return self._core.api.get(ref)
         for storage_class in self.all():
             if storage_class.name == name:
                 return storage_class
-        raise CTERAException('Could not find storage class.', name=name)
+        raise CTERAException(f'Storage class not found: {ref}')
