@@ -1,6 +1,4 @@
 __all__ = [
-    'connection',
-    'query',
     'afp',
     'aio',
     'array',
@@ -9,9 +7,11 @@ __all__ = [
     'cache',
     'cli',
     'config',
+    'connection',
     'directoryservice',
     'drive',
     'enum',
+    'files',
     'ftp',
     'groups',
     'licenses',
@@ -22,9 +22,11 @@ __all__ = [
     'nfs',
     'ntp',
     'power',
+    'query',
+    'remote',
     'rsync',
+    'ransom_protect',
     'services',
-    'session',
     'shares',
     'shell',
     'smb',
@@ -35,8 +37,4 @@ __all__ = [
     'timezone',
     'users',
     'volumes',
-    'files',
-    'remote',
-    'uri',
-    'decorator'
 ]
