@@ -419,10 +419,21 @@ class SourceType:
 
 class TaskType:
     """
-    Migration Tool Task Type
+    CTERA Migrate Task Type
 
     :ivar str Discovery: Discovery
     :ivar str Migration: Migration
     """
     Discovery = 0
     Migration = 1
+
+
+class ResourceError:
+    """
+    Resource Error
+
+    :ivar str FileExists: File exists
+    :ivar str Forbidden: Migration
+    """
+    FileExists = 'File exists'
+    Forbidden = 'Creating a folder in this location is forbidden'
