@@ -1,6 +1,6 @@
 from ..base_command import BaseCommand
-from ...cio.edge import EdgePath
-from ...lib.storage import synfs, commonfs
+from ...cio.edge import EdgePath, ListDirectory, RecursiveIterator, GetMetadata, Open, OpenMany, Upload, \
+     UploadFile, CreateDirectory, Copy, Move, Delete, Download, DownloadMany, Rename
 from . import io
 
 
@@ -13,7 +13,7 @@ class FileBrowser(BaseCommand):
 
         :param str path: Path
         """
-        return io.listdir(self._edge, self.normalize(path))
+        return ListDirectory(io.listdir, self._edge, self.normalize(path)).execute()
 
     def walk(self, path=None):
         """
@@ -21,7 +21,7 @@ class FileBrowser(BaseCommand):
 
         :param str,optional path: Path to walk, defaults to the root directory
         """
-        return io.walk(self._edge, path)
+        return RecursiveIterator(io.listdir, self._edge, self.normalize(path)).generate()
 
     def exists(self, path):
         """
@@ -29,7 +29,8 @@ class FileBrowser(BaseCommand):
 
         :param str path: Path
         """
-        return io.exists(self._edge, self.normalize(path))
+        with GetMetadata(io.listdir, self._edge, self.normalize(path), True) as (exists, *_):
+            return exists
 
     def handle(self, path):
         """
@@ -37,8 +38,7 @@ class FileBrowser(BaseCommand):
 
         :param str path: Path to a file
         """
-        handle_function = io.handle(self.normalize(path))
-        return handle_function(self._edge)
+        return Open(io.handle, self._edge, self.normalize(path)).execute()
 
     def handle_many(self, directory, *objects):
         """
@@ -47,8 +47,7 @@ class FileBrowser(BaseCommand):
         :param str directory: Path to a folder
         :param args objects: List of files and folders
         """
-        handle_many_function = io.handle_many(self.normalize(directory), *objects)
-        return handle_many_function(self._edge)
+        return OpenMany(io.handle_many, self._edge, directory, *objects).execute()
 
     def download(self, path, destination=None):
         """
@@ -58,9 +57,7 @@ class FileBrowser(BaseCommand):
         :param str,optional destination:
          File destination, if it is a directory, the original filename will be kept, defaults to the default directory
         """
-        directory, name = commonfs.determine_directory_and_filename(path, destination=destination)
-        handle = self.handle(path)
-        return synfs.write(directory, name, handle)
+        return Download(io.handle, self._edge, self.normalize(path), destination).execute()
 
     def download_many(self, target, objects, destination=None):
         """
@@ -78,9 +75,7 @@ class FileBrowser(BaseCommand):
             Optional. Path to the destination file or directory. If a directory is provided,
             the original filename will be preserved. Defaults to the default download directory.
         """
-        directory, name = commonfs.determine_directory_and_filename(target, objects, destination=destination, archive=True)
-        handle = self.handle_many(target, *objects)
-        return synfs.write(directory, name, handle)
+        return DownloadMany(io.handle_many, self._edge, self.normalize(target), objects, destination).execute()
 
     def upload(self, name, destination, handle):
         """
@@ -90,8 +85,7 @@ class FileBrowser(BaseCommand):
         :param str destination: Path to remote directory.
         :param object handle: Handle.
         """
-        upload_function = io.upload(name, self.normalize(destination), handle)
-        return upload_function(self._edge)
+        return Upload(io.upload, self._edge, io.listdir, name, self.normalize(destination), handle).execute()
 
     def upload_file(self, path, destination):
         """
@@ -100,10 +94,7 @@ class FileBrowser(BaseCommand):
         :param str path: Local path
         :param str destination: Remote path
         """
-        metadata = commonfs.properties(path)
-        with open(path, 'rb') as handle:
-            response = self.upload(metadata['name'], destination, handle)
-        return response
+        return UploadFile(io.upload, self._edge, io.listdir, path, self.normalize(destination)).execute()
 
     def mkdir(self, path):
         """
@@ -111,7 +102,7 @@ class FileBrowser(BaseCommand):
 
         :param str path: Directory path
         """
-        return io.mkdir(self._edge, self.normalize(path))
+        return CreateDirectory(io.mkdir, self._edge, self.normalize(path)).execute()
 
     def makedirs(self, path):
         """
@@ -119,7 +110,7 @@ class FileBrowser(BaseCommand):
 
         :param str path: Directory path
         """
-        return io.makedirs(self._edge, self.normalize(path))
+        return CreateDirectory(io.mkdir, self._edge, self.normalize(path), True).execute()
 
     def copy(self, path, destination=None, overwrite=False):
         """
@@ -129,9 +120,7 @@ class FileBrowser(BaseCommand):
         :param str destination: Destination folder path
         :param bool,optional overwrite: Overwrite on conflict, defaults to False
         """
-        if destination is None:
-            raise ValueError('Copy destination was not specified.')
-        return io.copy(self._edge, self.normalize(path), self.normalize(destination), overwrite)
+        return Copy(io.copy, self._edge, self.normalize(path), self.normalize(destination), overwrite).execute()
 
     def move(self, path, destination=None, overwrite=False):
         """
@@ -141,18 +130,25 @@ class FileBrowser(BaseCommand):
         :param str destination: Destination folder path
         :param bool,optional overwrite: Overwrite on conflict, defaults to False
         """
-        if destination is None:
-            raise ValueError('Move destination was not specified.')
-        return io.move(self._edge, self.normalize(path), self.normalize(destination), overwrite)
+        return Move(io.move, self._edge, self.normalize(path), self.normalize(destination), overwrite).execute()
 
-    def delete(self, *paths):
+    def rename(self, path, name):
+        """
+        Rename a file
+
+        :param str path: Path of the file or directory to rename
+        :param str name: The name to rename to
+        """
+        return Rename(io.move, self._edge, self.normalize(path), name).execute()
+
+    def delete(self, path):
         """
         Delete a file
 
         :param str path: File path
         """
-        return io.remove(self._edge, *[self.normalize(path) for path in paths])
+        return Delete(io.delete, self._edge, self.normalize(path)).execute()
 
     @staticmethod
     def normalize(path):
-        return EdgePath('/', path)
+        return EdgePath.instance('/', path)
