@@ -1,7 +1,6 @@
 import logging
 
 from ..lib import track, ErrorStatus
-from .taskmgr import Task
 from .enum import Mode, SyncStatus, Acl
 from .base_command import BaseCommand
 from ..common import Object, ThrottlingRule, FilterBackupSet, FileFilterBuilder
@@ -170,15 +169,16 @@ class Sync(BaseCommand):
 
         :param str path: Directory path
         :param bool wait: Wait for eviction task to complete, defaults to ``False``
-        :returns: A reference to the background task
-        :rtype: str
+        :returns: Task status object, or an awaitable task object
+        :rtype: cterasdk.common.object.Object or :class:`cterasdk.lib.tasks.AwaitableEdgeTask`
         """
         param = Object()
+        param._classname = 'evictFolderParam'  # pylint: disable=protected-access
         param.path = path
         ref = self._edge.api.execute('/config/cloudsync', 'evictFolder', param)
         if wait:
-            Task(self._edge, ref).wait()
-        return ref
+            return self._edge.tasks.wait(ref)
+        return self._edge.tasks.awaitable_task(ref)
 
 
 class CloudSyncBandwidthThrottling(BaseCommand):
