@@ -1,5 +1,7 @@
 from . import (  # noqa: E402, F401
+    auth,
     backup,
+    common,
     direct,
     io,
     notifications,
