@@ -4,8 +4,10 @@ class CTERAException(Exception):
 
     :parm str message: Error message
     """
-    def __init__(self, message=None):
+    def __init__(self, message=None, **kwargs):
         super().__init__(message)
+        for k, v in kwargs.items():
+            setattr(self, k, v)
 
     def __repr__(self):
         return str(self)
