@@ -5,7 +5,7 @@ class SessionExpired(CTERAException):
     """Session expiration"""
 
     def __init__(self):
-        super().__init__('Authentication error: Session expired.')
+        super().__init__('Authentication error: Session expired. Please log in again.')
 
 
 class NotLoggedIn(CTERAException):
@@ -16,7 +16,7 @@ class NotLoggedIn(CTERAException):
 
 
 class ContextError(CTERAException):
-    """API invocation context rrror"""
+    """API invocation context error"""
 
     def __init__(self, message):
         super().__init__(f'Context error: {message}.')
